@@ -167,6 +167,10 @@ OC.L10N.register(
     "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Aplikace Záložky může provádět každodenní automatickou zálohu vašich záložek a bránit tak ztrátě dat při jejich synchronizaci napříč zařízeními.",
     "Enable backups" : "Zapnout zálohování",
     "Enter the path of a folder in your Files where backups will be stored." : "Zadejte popis umístění složky ve svých Souborech, do kterého ukládat zálohy.",
+    "Context Chat integration" : "Napojení na kontextový chat",
+    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Aplikace Záložky může automaticky zpřístupňovat obsah webových stránek, kterých jste si do ní uložili adresy kontextovému chatu, což umožňuje pokládat dotazy a dostávat odpovědi založené na tomto obsahu. Toto je k dispozici pouze pokud je zapnutá automatická archivace.",
+    "Context chat is currently not installed, but is required for this feature." : "Kontextový chat v tuto chvíli není nainstalován, ale pro tuto funkci je potřebný.",
+    "Enable Context Chat integration" : "Zapnout napojení na kontextový chat",
     "Client apps" : "Klientské aplikace",
     "Also check out the collection of client apps that integrate with this app: " : "Také se podívejte na sadu klientských aplikací, které napojují na tuto aplikaci:",
     "Install web app" : "Nainstalovat webovou aplikaci",
