@@ -5,24 +5,24 @@ OC.L10N.register(
     "Rename" : "Ailenwi",
     "Copy link" : "Copïo dolen",
     "Move" : "Symud",
-    "Delete" : "Dileu",
     "Go back" : "Nôl",
     "New" : "Newydd",
     "New folder" : "Ffolder newydd",
+    "Search" : "Chwilio",
+    "Empty trash bin" : "Bin sbwriel gwag",
     "Cancel" : "Diddymu",
     "Recent" : "Diweddar",
     "Shared with you" : "Shared with you",
     "Files" : "Ffeiliau",
-    "Import" : "Mewnforio",
-    "Export" : "Allforio",
+    "Delete" : "Dileu",
     "Title" : "Teitl",
     "Link" : "Dolen",
     "Tags" : "Tagiau",
     "Notes" : "Nodiadau",
+    "Link copied" : "Dolen wedi'i gopïo",
     "Owner" : "Owner",
     "Share link" : "Rhannu dolen",
     "Allow editing" : "Caniatáu golygu",
-    "Link copied" : "Dolen wedi'i gopïo",
     "Folder" : "Plygell",
     "Save" : "Cadw"
 },
