@@ -169,6 +169,8 @@ OC.L10N.register(
     "Add to {instanceName}" : "Lisää kohteeseen {instanceName}",
     "Need help?" : "Tarvitsetko apua?",
     "Support this project" : "Tue tätä projektia",
+    "Created {time} ago" : "Luotu {time} sitten",
+    "Created on {date}" : "Luotu {date}",
     "Title" : "Otsikko",
     "Link" : "Linkki",
     "Untitled folder" : "Nimetön kansio",
@@ -231,6 +233,7 @@ OC.L10N.register(
     "Failed to move bookmark" : "Kirjanmerkin siirtäminen epäonnistui",
     "Failed to copy bookmark" : "Kirjanmerkin kopioiminen epäonnistui",
     "Failed to delete bookmark" : "Kirjanmerkin poistaminen epäonnistui",
+    "Import successful" : "Tuonti onnistui",
     "Failed to rename tag" : "Tunnisteen uudelleen nimeäminen epäonnistui",
     "Failed to load tags" : "Tunnisteiden lataaminen epäonnistui",
     "Failed to load folders" : "Kansioiden lataaminen epäonnistui",
@@ -239,6 +242,8 @@ OC.L10N.register(
     "Failed to delete folder" : "Kansion poistaminen epäonnistui",
     "Failed to move folder" : "Kansion siirtäminen epäonnistui",
     "Failed to create folder" : "Kansion luominen epäonnistui",
+    "Failed to move parts of selection" : "Joidenkin valinnan osien siirtäminen epäonnistui",
+    "Failed to delete parts of selection" : "Joidenkin valinnan osien poistaminen epäonnistui",
     "Failed to fetch bookmarks." : "Kirjanmerkkien noutaminen epäonnistui.",
     "Failed to load setting {key}" : "Asetuksen {key} lataaminen epäonnistui",
     "Failed to update share {shareId}" : "Jaon {shareId} päivittäminen epäonnistui",
