@@ -1,46 +1,55 @@
 OC.L10N.register(
     "bookmarks",
     {
+    "Link copied to clipboard" : "Линкот е копиран во клипборд",
     "Details" : "Детали",
     "Rename" : "Преименувај",
     "Copy link" : "Копирај линк",
     "Move" : "Премести",
-    "Delete" : "Избриши",
     "Delete selection" : "Избриши ги селектираните",
     "Select all" : "Избери се",
+    "RSS feed copied" : "RSS канал копиран",
     "Go back" : "Назад",
     "Share folder" : "Сподели папка",
     "New" : "Ново",
     "New folder" : "Нова папка",
     "Search" : "Барај",
-    "RSS feed copied" : "RSS канал копиран",
+    "Empty trash bin" : "Испразни ја корпата со отпадоци",
+    "Enter a link" : "Внеси линк",
+    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
+    "Shared by {user}" : "Споделено од {user}",
     "Rename folder" : "Преименувај папка",
-    "Delete folder" : "Избриши папка",
+    "Move folder" : "Премести папка",
     "Submit" : "Испрати",
     "Cancel" : "Откажи",
     "Recent" : "Неодамнешни",
     "Shared with you" : "Споделено со вас",
     "Files" : "Датотеки",
-    "Import" : "Увези",
-    "Export" : "Извези",
+    "Delete" : "Избриши",
+    "Need help?" : "Ви треба помош?",
+    "Created on {date}" : "Креиран на {date}",
     "Title" : "Наслов",
     "Link" : "Линк",
     "Tags" : "Ознаки",
     "Notes" : "Белешки",
     "Download file" : "Преземи датотека",
+    "Link copied" : "Линкот е копиран",
     "Owner" : "Сопственик",
     "Sharing" : "Споделување",
     "Select a user or group" : "Избери корисник или група",
     "Share link" : "Сподели линк",
     "Copy RSS feed" : "Копирај RSS канал",
+    "Create public link" : "Креирај јавен линк",
     "Allow editing" : "Овозможи уредување",
     "Allow resharing" : "Дозволи повторно споделување",
     "Remove share" : "Отстрани споделување",
-    "Link copied" : "Линкот е копиран",
-    "Privacy" : "Приватност",
     "Failed to save settings" : "Неуспешно зачувување на параметрите",
     "Failed to load settings" : "Неуспешно вчитување на параметрите",
+    "Privacy" : "Приватност",
+    "Performance" : "Перформанси",
     "Folder" : "Папка",
-    "Save" : "Зачувај"
+    "Save" : "Зачувај",
+    "What's new?" : "Што е ново",
+    "Failed to load tags" : "Неуспешно вчитување на ознаки"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
