@@ -176,6 +176,8 @@ OC.L10N.register(
     "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Hvis du har problemer med denne bokmerkeappen eller har en ide om hva som kan forbedres, ikke nøl med å ta kontakt ved å klikke her.",
     "Support this project" : "Støtt dette prosjektet",
     "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Arbeidet mitt med denne bokmerkeappen drives av en frivillig abonnementsmodell. Hvis du tror det jeg gjør er verdt din oppmerksomhet, ville jeg være glad hvis du kunne støtte mitt arbeid. Vurder også å gi appen en anmeldelse i Nextcloud App Store. Takk 💙 ",
+    "Created {time} ago" : "Opprettet {time} siden",
+    "Created on {date}" : "Opprettet den {date}",
     "(Empty title)" : "(tom tittel)",
     "Title" : "Tittel",
     "Link" : "Lenke",
@@ -246,6 +248,7 @@ OC.L10N.register(
     "Failed to move bookmark" : "Flytting av bokmerke feilet",
     "Failed to copy bookmark" : "Kopiering av bokmerke feilet",
     "Failed to delete bookmark" : "Sletting av bokmerke feilet",
+    "Import successful" : "Import vellykket",
     "Failed to rename tag" : "Omdøping av merkelapp feilet",
     "Failed to load tags" : "Lasting av merkelapper feilet",
     "Failed to load folders" : "Lasting av mapper feilet",
