@@ -3,20 +3,23 @@ OC.L10N.register(
     {
     "Details" : "معلومات",
     "Rename" : "نوم بدلول",
+    "Copy link" : "لېنک کاپي کول",
     "Move" : "انتقال",
-    "Delete" : "ړنګول",
+    "Select all" : "ټول ټاکل",
     "New" : "نوی",
     "New folder" : "نوی فولډر",
-    "Select all" : "ټول ټاکل",
+    "_%n folder_::_%n folders_" : ["%n فولډر","%n فولډرونه"],
     "Cancel" : "پرېښول",
     "Recent" : "وروستي",
+    "Shared with you" : "تاسې سره شريک شوي",
+    "Files" : "فایلونه",
+    "Delete" : "ړنګول",
+    "Created on {date}" : "په {date} جوړ شوی",
     "Link" : "لېنک",
     "Tags" : "نښکې",
     "Notes" : "شسیب",
     "Share link" : "د شرېکېدو لېنک",
-    "Copy link" : "لېنک کاپي کول",
     "Allow editing" : "د سمون اجازه ورکول",
-    "Select" : "ټاکل",
     "Save" : "ساتل"
 },
 "nplurals=2; plural=(n != 1);");
