@@ -104,6 +104,7 @@ OC.L10N.register(
     "_%n bookmark_::_%n bookmarks_" : ["%n bokmärke","%n bokmärken"],
     "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
     "Welcome to Bookmarks" : "Välkommen till Bokmärken",
+    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Denna app låter dig hantera länkar till dina favoritplatser på webben. Sortera dina bokmärken i mappar, märk dem med taggar och dela dem med andra! Appen kontrollerar regelbundet alla dina länkar för tillgänglighet och visar otillgängliga länkar. Om du lägger till en länk till en fil på webben kommer filen automatiskt att laddas ner till dina Nextcloud-filer. Du kan också importera bokmärken som exporterats från andra tjänster eller direkt synkronisera bokmärken från alla dina webbläsare med denna app.",
     "Add a bookmark" : "Lägg till ett bokmärke",
     "Import bookmarks" : "Importera bokmärken",
     "Sync with your browser" : "Synkronisera med din webbläsare",
@@ -166,6 +167,10 @@ OC.L10N.register(
     "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Bokmärkesappen kan automatiskt säkerhetskopiera dina bokmärken dagligen för att förhindra dataförlust när du synkroniserar bokmärken mellan enheter.",
     "Enable backups" : "Aktivera säkerhetskopiering",
     "Enter the path of a folder in your Files where backups will be stored." : "Ange sökvägen till en mapp i dina filer där säkerhetskopior kommer att lagras.",
+    "Context Chat integration" : "Integration med kontextchatt",
+    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Bokmärkesappen kan automatiskt göra det textuella innehållet på de webbplatser du bokmärker tillgängligt för Kontextchatt, vilket gör att du kan ställa frågor om och få svar baserade på det innehållet. Detta är endast tillgängligt om autoarkivering är aktiverad.",
+    "Context chat is currently not installed, but is required for this feature." : "Kontextchatt är för närvarande inte installerad, men krävs för denna funktion.",
+    "Enable Context Chat integration" : "Aktivera integration med kontextchatt",
     "Client apps" : "Klientappar",
     "Also check out the collection of client apps that integrate with this app: " : "Kolla också in samlingen av klientappar som integrerar med den här appen: ",
     "Install web app" : "Installera webbapp",
@@ -243,6 +248,7 @@ OC.L10N.register(
     "Failed to count unavailable bookmarks" : "Det gick inte att räkna otillgängliga bokmärken",
     "Failed to count archived bookmarks" : "Det gick inte att räkna arkiverade bokmärken",
     "Failed to count duplicated bookmarks" : "Det gick inte att räkna dubblerade bokmärken",
+    "Failed to count bookmarks" : "Kunde inte räkna bokmärken",
     "Failed to load bookmark" : "Det gick inte att läsa in bokmärket",
     "Failed to find existing bookmark" : "Kunde inte hitta befintligt bokmärke",
     "Failed to create bookmark" : "Kunde inte skapa bokmärke",
@@ -250,6 +256,7 @@ OC.L10N.register(
     "Failed to move bookmark" : "Kunde inte flytta bokmärke",
     "Failed to copy bookmark" : "Kunde inte kopiera bokmärket",
     "Failed to delete bookmark" : "Kunde inte radera bokmärke",
+    "Failed to restore bookmark" : "Kunde inte återställa bokmärke",
     "Import successful" : "Importen lyckades",
     "Failed to rename tag" : "Kunde inte döpa om tagg",
     "Failed to load tags" : "Kunde inte läsa in taggar",
@@ -258,14 +265,22 @@ OC.L10N.register(
     "Failed to load deleted bookmarks" : "Kunde inte läsa in borttagna bokmärken",
     "Failed to delete folder" : "Kunde inte radera mapp",
     "Failed to move folder" : "Det gick inte att flytta mappen",
+    "Failed to restore folder" : "Kunde inte återställa mapp",
     "Failed to create folder" : "Kunde inte skapa mapp",
+    "Failed to load children order" : "Kunde inte läsa in underordnade objekt",
     "Failed to move parts of selection" : "Kunde inte flytta vissa delar av urvalet",
+    "Failed to copy parts of selection" : "Kunde inte kopiera delar av markeringen",
     "Failed to delete parts of selection" : "Kunde inte ta bort delar av urvalet",
+    "Failed to tag parts of selection" : "Kunde inte tagga delar av markeringen",
     "Failed to fetch bookmarks." : "Kunde inte hämta bokmärken.",
     "Failed to store setting" : "Kunde inte spara inställning",
     "Failed to load setting {key}" : "Det gick inte att läsa in inställningen {key}",
+    "Failed to create share for folder {folderId}" : "Kunde inte skapa delning för mappen {folderId}",
     "Failed to update share {shareId}" : "Det gick inte att uppdatera delningen {shareId}",
     "Failed to delete share {shareId}" : "Det gick inte att radera delningen {shareId}",
+    "Failed to create public link for folder {folderId}" : "Kunde inte skapa offentlig länk för mappen {folderId}",
+    "Failed to delete public link for folder {folderId}" : "Kunde inte ta bort offentlig länk för mappen {folderId}",
+    "Failed to permanently delete parts of trash bin" : "Kunde inte permanent ta bort delar av papperskorgen",
     "Create bookmarks for mentioned links" : "Skapa bokmärken för nämnda länkar",
     "No links found in this message" : "Inga länkar hittades i detta meddelande",
     "Bookmarks feed" : "Bokmärkesflöde"
