@@ -1,4 +1,5 @@
 <?php
+
 /*
  * Copyright (c) 2022. The Nextcloud Bookmarks contributors.
  *
@@ -7,21 +8,18 @@
 
 namespace OCA\Bookmarks\Command;
 
+use OCA\Bookmarks\Db\BookmarkMapper;
 use OCA\Bookmarks\Service\FileCache;
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Output\OutputInterface;
 
 class ClearPreviews extends Command {
-
-	/**
-	 * @var FileCache
-	 */
-	private $fileCache;
-
-	public function __construct(FileCache $fileCache) {
+	public function __construct(
+		private FileCache $fileCache,
+		private BookmarkMapper $bookmarkMapper,
+	) {
 		parent::__construct();
-		$this->fileCache = $fileCache;
 	}
 
 	/**
@@ -37,7 +35,7 @@ class ClearPreviews extends Command {
 	/**
 	 * Execute the command
 	 *
-	 * @param InputInterface  $input
+	 * @param InputInterface $input
 	 * @param OutputInterface $output
 	 *
 	 * @return int
@@ -45,6 +43,7 @@ class ClearPreviews extends Command {
 	protected function execute(InputInterface $input, OutputInterface $output): int {
 		try {
 			$this->fileCache->clear();
+			$this->bookmarkMapper->clearLastPreviews();
 		} catch (\Exception $ex) {
 			$output->writeln('<error>Failed to clear previews</error>');
 			$output->writeln($ex->getMessage());
