@@ -9,6 +9,8 @@
 namespace OCA\Bookmarks\Db;
 
 use OCA\Bookmarks\Events\BeforeDeleteEvent;
+use OCA\Bookmarks\Events\InsertEvent;
+use OCA\Bookmarks\Events\ManipulateEvent;
 use OCA\Bookmarks\Exception\AlreadyExistsError;
 use OCA\Bookmarks\Exception\UrlParseError;
 use OCA\Bookmarks\Exception\UserLimitExceededError;
@@ -185,7 +187,7 @@ class BookmarkMapper extends QBMapper {
 		$qb
 			->select(Bookmark::$columns)
 			->from('bookmarks')
-			->where($qb->expr()->eq('id', $qb->createNamedParameter($id)));
+			->where($qb->expr()->eq('id', $qb->createNamedParameter($id, IQueryBuilder::PARAM_INT)));
 
 		return $this->findEntity($qb);
 	}
@@ -220,8 +222,8 @@ class BookmarkMapper extends QBMapper {
 
 		$qb
 			->from('*PREFIX*bookmarks', 'b')
-			->innerJoin('b', 'folder_tree', 'tree', 'tree.item_id = b.id AND tree.type = ' . $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK) .
-				($queryParams->getSoftDeleted() ? ' AND tree.soft_deleted_at is NOT NULL' : ' AND tree.soft_deleted_at is NULL'));
+			->innerJoin('b', 'folder_tree', 'tree', 'tree.item_id = b.id AND tree.type = ' . $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK)
+				. ($queryParams->getSoftDeleted() ? ' AND tree.soft_deleted_at is NOT NULL' : ' AND tree.soft_deleted_at is NULL'));
 
 		$this->_filterUrl($qb, $queryParams);
 		$this->_filterArchived($qb, $queryParams);
@@ -257,6 +259,21 @@ class BookmarkMapper extends QBMapper {
 		return $entities;
 	}
 
+	/**
+	 * @throws \OCP\DB\Exception
+	 */
+	protected function getIteratorWithRawQuery(string $query, array $params, array $types): \Generator {
+		$cursor = $this->db->executeQuery($query, $params, $types);
+
+		$entities = [];
+
+		while ($row = $cursor->fetch()) {
+			yield $this->mapRowToEntity($row);
+		}
+
+		$cursor->closeCursor();
+	}
+
 	/**
 	 * Common table expression that lists all items in a given folder, recursively
 	 * @param int $folderId
@@ -298,9 +315,9 @@ class BookmarkMapper extends QBMapper {
 
 		if ($this->getDbType() === 'mysql') {
 			// For mysql we can just throw these three queries together in a CTE
-			$withRecursiveQuery = 'WITH RECURSIVE folder_tree(item_id, parent_folder, type, idx, soft_deleted_at) AS ( ' .
-				$baseCase->getSQL() . ' UNION ALL ' . $recursiveCase->getSQL() .
-				' UNION ALL ' . $recursiveCaseShares->getSQL() . ')';
+			$withRecursiveQuery = 'WITH RECURSIVE folder_tree(item_id, parent_folder, type, idx, soft_deleted_at) AS ( '
+				. $baseCase->getSQL() . ' UNION ALL ' . $recursiveCase->getSQL()
+				. ' UNION ALL ' . $recursiveCaseShares->getSQL() . ')';
 		} else {
 			// Postgres loves us dearly and doesn't allow two recursive references in one CTE, aaah.
 			// So we nest them:
@@ -333,12 +350,12 @@ class BookmarkMapper extends QBMapper {
 			// then we need another instance of the first recursive case, duplicated here as secondRecursive case
 			// to recurse into child folders of shared folders
 			// Note: This doesn't cover cases where a shared folder is inside a shared folder.
-			$withRecursiveQuery = 'WITH RECURSIVE folder_tree(item_id, parent_folder, type, idx, soft_deleted_at) AS ( ' .
-				'WITH RECURSIVE second_folder_tree(item_id, parent_folder, type, idx, soft_deleted_at) AS (' .
-				'WITH RECURSIVE inner_folder_tree(item_id, parent_folder, type, idx, soft_deleted_at) AS ( ' .
-				$baseCase->getSQL() . ' UNION ALL ' . $recursiveCase->getSQL() . ')' .
-				' ' . $secondBaseCase->getSQL() . ' UNION ALL ' . $recursiveCaseShares->getSQL() . ')' .
-				' ' . $thirdBaseCase->getSQL() . ' UNION ALL ' . $secondRecursiveCase->getSQL() . ')';
+			$withRecursiveQuery = 'WITH RECURSIVE folder_tree(item_id, parent_folder, type, idx, soft_deleted_at) AS ( '
+				. 'WITH RECURSIVE second_folder_tree(item_id, parent_folder, type, idx, soft_deleted_at) AS ('
+				. 'WITH RECURSIVE inner_folder_tree(item_id, parent_folder, type, idx, soft_deleted_at) AS ( '
+				. $baseCase->getSQL() . ' UNION ALL ' . $recursiveCase->getSQL() . ')'
+				. ' ' . $secondBaseCase->getSQL() . ' UNION ALL ' . $recursiveCaseShares->getSQL() . ')'
+				. ' ' . $thirdBaseCase->getSQL() . ' UNION ALL ' . $secondRecursiveCase->getSQL() . ')';
 		}
 
 		// Now we need to concatenate the params of all these queries for downstream assembly of the greater query
@@ -454,9 +471,10 @@ class BookmarkMapper extends QBMapper {
 	private function _filterDuplicated(IQueryBuilder $qb, QueryParameters $params) {
 		if ($params->getDuplicated()) {
 			$subQuery = $this->db->getQueryBuilder();
+			$subQuery->automaticTablePrefix(false);
 			$subQuery->select('trdup.parent_folder')
-				->from('*PREFIX*bookmarks_tree', 'trdup')
-				->where($subQuery->expr()->eq('b.id', 'trdup.id'))
+				->from('folder_tree', 'trdup')
+				->where($subQuery->expr()->eq('b.id', 'trdup.item_id'))
 				->andWhere($subQuery->expr()->neq('trdup.parent_folder', 'tree.parent_folder'))
 				->andWhere($subQuery->expr()->eq('trdup.type', $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK)));
 			$qb->andWhere($qb->createFunction('EXISTS(' . $subQuery->getSQL() . ')'));
@@ -718,18 +736,30 @@ class BookmarkMapper extends QBMapper {
 		$qb = $this->db->getQueryBuilder();
 		$qb->select(Bookmark::$columns);
 		$qb->from('bookmarks', 'b');
-		$qb->where($qb->expr()->lt('last_preview', $qb->createPositionalParameter($this->time->getTime() - $stalePeriod)));
+		$qb->where($qb->expr()->lt('last_preview', $qb->createPositionalParameter($this->time->getTime() - $stalePeriod, IQueryBuilder::PARAM_INT)));
 		$qb->orWhere($qb->expr()->isNull('last_preview'));
 		$qb->setMaxResults($limit);
 		return $this->findEntities($qb);
 	}
 
+	/**
+	 * @return void
+	 * @throws Exception
+	 */
+	public function clearLastPreviews(): void {
+		$qb = $this->db->getQueryBuilder();
+		$qb->update('bookmarks');
+		$qb->set('last_preview', $qb->createNamedParameter(0, IQueryBuilder::PARAM_INT));
+		$qb->executeStatement();
+	}
+
 	/**
 	 * @psalm-param Bookmark $entity
 	 * @param Entity $entity
 	 *
 	 * @return Bookmark
 	 * @psalm-return Bookmark
+	 * @throws Exception
 	 */
 	public function delete(Entity $entity): Bookmark {
 		$this->eventDispatcher->dispatch(
@@ -760,7 +790,9 @@ class BookmarkMapper extends QBMapper {
 			$entity->setUrl($this->urlNormalizer->normalize($entity->getUrl()));
 		}
 		$entity->setLastmodified(time());
-		return parent::update($entity);
+		parent::update($entity);
+		$this->eventDispatcher->dispatchTyped(new ManipulateEvent('bookmark', $entity->getId()));
+		return $entity;
 	}
 
 	/**
@@ -793,6 +825,7 @@ class BookmarkMapper extends QBMapper {
 			$this->findByUrl($entity->getUserId(), $entity->getUrl());
 		} catch (DoesNotExistException $e) {
 			parent::insert($entity);
+			$this->eventDispatcher->dispatchTyped(new InsertEvent('bookmark', $entity->getId()));
 			return $entity;
 		} catch (MultipleObjectsReturnedException $e) {
 			// noop
@@ -891,4 +924,41 @@ class BookmarkMapper extends QBMapper {
 			return  $share->getOwner();
 		}, $this->shareMapper->findByUser($userId));
 	}
+
+	public function getIterator(string $userId, QueryParameters $queryParams): \Generator {
+		$rootFolder = $this->folderMapper->findRootFolder($userId);
+		// gives us all bookmarks in this folder, recursively
+		[$cte, $params, $paramTypes] = $this->_generateCTE($rootFolder->getId(), $queryParams->getSoftDeletedFolders());
+
+		$qb = $this->db->getQueryBuilder();
+		$bookmark_cols = array_map(static function ($c) {
+			return 'b.' . $c;
+		}, Bookmark::$columns);
+
+		$qb->select($bookmark_cols);
+		$qb->groupBy($bookmark_cols);
+
+		$qb->automaticTablePrefix(false);
+
+		$qb
+			->from('*PREFIX*bookmarks', 'b')
+			->innerJoin('b', 'folder_tree', 'tree', 'tree.item_id = b.id AND tree.type = ' . $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK)
+				. ($queryParams->getSoftDeleted() ? ' AND tree.soft_deleted_at is NOT NULL' : ' AND tree.soft_deleted_at is NULL'));
+
+		$this->_filterUrl($qb, $queryParams);
+		$this->_filterArchived($qb, $queryParams);
+		$this->_filterUnavailable($qb, $queryParams);
+		$this->_filterDuplicated($qb, $queryParams);
+		$this->_filterFolder($qb, $queryParams);
+		$this->_filterTags($qb, $queryParams);
+		$this->_filterUntagged($qb, $queryParams);
+		$this->_filterSearch($qb, $queryParams);
+		$this->_sortAndPaginate($qb, $queryParams);
+
+		$finalQuery = $cte . ' ' . $qb->getSQL();
+
+		$params = array_merge($params, $qb->getParameters());
+		$paramTypes = array_merge($paramTypes, $qb->getParameterTypes());
+		return $this->getIteratorWithRawQuery($finalQuery, $params, $paramTypes);
+	}
 }
